@@ -18,6 +18,26 @@ class Vector2:
         self.x = x
         self.y = y
 
+    @property
+    def lenght(self):
+        return sqrt(self.x**2 + self.y**2)
+
+    @property
+    def unity(self):
+        return Vector2(self.x/self.lenght,self.y/self.lenght) if self.lenght > 0 else Vector2(0,0)
+
+    @property
+    def arg(self):
+        if self.x > 0:
+            return atan(self.y/self.x)
+        elif self.x < 0 and self.y >= 0:
+            return atan(self.y/self.x) + pi
+        elif self.x < 0 and self.y < 0:
+            return atan(self.y/self.x) - pi
+        elif self.x==0 and self.y < 0: return -pi/2
+        elif self.x ==0 and self.y > 0: return pi/2
+        else: return None
+
     def __str__(self) -> str:
         return f'({self.x},{self.y})'
 
@@ -25,14 +45,37 @@ class Vector2:
         """return a tuple of the vector"""
         return (self.x,self.y)
     
+    def copy(self):
+        return Vector2(self.x,self.y)
+
+    def __iter__(self):
+        return iter((self.x, self.y))
+
     def __add__(self,other):
         if type(other)==Vector2:
             return Vector2(self.x + other.x, self.y + other.y)
+        if type(other)==tuple:
+            return Vector2(self.x + other[0], self.y + other[1])
         else:
             raise TypeError("You can just add Vector2 between them but you pass :", type(other))
-    
-    def copy(self):
-        return Vector2(self.x,self.y)
+
+    def __iadd__(self,other):
+        return self.__add__(other)
+
+    def __sub__(self,other):
+        if type(other)==Vector2:
+            return Vector2(self.x - other.x, self.y - other.y)
+        if type(other)==tuple:
+            return Vector2(self.x - other[0], self.y - other[1])
+        else:
+            raise TypeError("You can just substract Vector2 between them but you pass :", type(other))
+
+    def __isub__(self,other):
+        return self.__min__(other)
+
+    def __mul__(self,other):
+        if type(other)==int or type(other)==float:
+            return Vector2(self.x*other,self.y*other)
 
 class Menu_Manager(object):
     """
@@ -349,7 +392,7 @@ class Button(sprite):
         _text.fit_to_size()
          
         self.image.blit(_text.image,(0,0))
-
+#! rewrite
 class InputBox(sprite):
     """
     class de InputBox autonome, permet de rentrer du texte facilement
@@ -430,7 +473,7 @@ class InputBox(sprite):
             ecran.blit(render,(self.position.x,self.position.y))
 
     def Enter_func(self,_event): ...
-
+#! rewrite
 class AlertBox(sprite):
     """
     class de alertbox autonome, permet de rentrer d'afficher une erreur facilement
@@ -546,6 +589,39 @@ class AlertBox(sprite):
 
     def Enter_func(self,_event): ...
 
+class ScrollableBox(sprite,py.sprite.Group):
+
+    def __init__(self, name, size, manager: Menu_Manager, isactive=True, layer=0):
+        super().__init__()
+        self.name = name
+        self.layer = layer
+        self.isactive = isactive
+        self._manager = manager
+        
+        self.handles = []
+
+        self.rect = py.Rect(0,0,*size)
+        self.initial_size = Vector2(self.image.get_width(),self.image.get_height())
+        super(py.sprite.Group,self).__init__()
+
+    def add_sprite(self,sp:sprite):
+        self.add(sp)
+
+    def update(self, *args, **kwargs):
+        super(py.sprite.Group,self).update(*args, **kwargs)
+        return super(sprite,self).update(*args, **kwargs)
+
+    @property
+    def image(self):
+        _surf = py.Surface(self.rect.size,flags=py.SRCALPHA)
+        self.draw(_surf)
+        return _surf
+
+    def Handle(self, _event:py.event.Event,*arg, **kargs):
+        if _event.type == py.MOUSEWHEEL:
+            self.rect -= _event.y
+        return super().Handle(_event,*arg, **kargs)
+
 class Menu(py.sprite.Group):
     """
     classe principale du Menu
